package com.ruoyi.project.VRdemo.controller;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.alibaba.excel.EasyExcel;
import com.ruoyi.common.utils.excel.ExcelReadUtil;
import com.ruoyi.framework.aspectj.lang.annotation.Anonymous;
import com.ruoyi.project.VRdemo.domain.imData.InstitutionImData;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.VRdemo.domain.Institution;
import com.ruoyi.project.VRdemo.service.IInstitutionService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 博雅集东南亚研究机构Controller
 *
 * @author ruoyi
 * @date 2024-09-26
 */
@RestController
@RequestMapping("/vr/institution")
public class InstitutionController extends BaseController {

    private final IInstitutionService institutionService;

    public InstitutionController(@Autowired IInstitutionService institutionService) {
        this.institutionService = institutionService;
    }

    /**
     * 查询博雅集东南亚研究机构列表
     */
    @Anonymous
    @GetMapping("/list")
    public AjaxResult list(Institution institution) {
        List<Institution> list = institutionService.selectInstitutionList(institution);

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 200);
        ajaxResult.put("rows", list);
        ajaxResult.put("total", list.size());
        return ajaxResult;
    }

    /**
     * 查询分页列表
     */
    @GetMapping("/pageList")
    public TableDataInfo pageList(Institution institution) {
        startPage();
        List<Institution> list = institutionService.selectInstitutionList(institution);
        return getDataTable(list);
    }

    /**
     * 获取博雅集东南亚研究机构详细信息
     */
    @Anonymous
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(institutionService.selectInstitutionById(id));
    }

    /**
     * 新增博雅集东南亚研究机构
     */
    @PreAuthorize("@ss.hasPermi('VRdemo:institution:add')")
    @Log(title = "博雅集东南亚研究机构", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Institution institution) {
        return toAjax(institutionService.insertInstitution(institution));
    }

    /**
     * 修改博雅集东南亚研究机构
     */
    @PreAuthorize("@ss.hasPermi('VRdemo:institution:edit')")
    @Log(title = "博雅集东南亚研究机构", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Institution institution) {
        return toAjax(institutionService.updateInstitution(institution));
    }

    /**
     * 删除博雅集东南亚研究机构
     */
    @PreAuthorize("@ss.hasPermi('VRdemo:institution:remove')")
    @Log(title = "博雅集东南亚研究机构", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(institutionService.deleteInstitutionByIds(ids));
    }

    /**
     * 导出博雅集东南亚研究机构列表
     */
    @PreAuthorize("@ss.hasPermi('VRdemo:institution:export')")
    @Log(title = "博雅集东南亚研究机构", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Institution institution) {
        List<Institution> list = institutionService.selectInstitutionList(institution);
        ExcelUtil<Institution> util = new ExcelUtil<>(Institution.class);
        util.exportExcel(response, list, "博雅集东南亚研究机构数据");
    }

    /**
     * 下载导入模板
     */
    @Anonymous
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response) throws IOException {
        List<InstitutionImData> dataList = new ArrayList<>();
        EasyExcel.write(response.getOutputStream(), InstitutionImData.class).sheet("Sheet1").doWrite(dataList);
    }

    /**
     * 导入数据
     */
    @Anonymous
    @PostMapping("/import")
    public AjaxResult importData(MultipartFile file, boolean updateSupport) throws IOException {

        List<Institution> list = ExcelReadUtil.read(file, InstitutionImData.class, Institution.class);

        // 调用服务层方法进行数据导入处理
        String message = institutionService.importData(list, updateSupport);

        // 返回成功响应，携带导入结果信息
        return AjaxResult.success(message);
    }
}
