package com.ruoyi.project.VRdemo.controller;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.alibaba.excel.EasyExcel;
import com.ruoyi.common.utils.excel.ExcelReadUtil;
import com.ruoyi.framework.aspectj.lang.annotation.Anonymous;
import com.ruoyi.project.VRdemo.domain.Thesis;
import com.ruoyi.project.VRdemo.domain.imData.PressImData;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.VRdemo.domain.Press;
import com.ruoyi.project.VRdemo.service.IPressService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * pressController
 *
 * @author ruoyi
 * @date 2024-01-19
 */
@RestController
@RequestMapping("/vr/press")
public class PressController extends BaseController {

    private final IPressService pressService;

    public PressController(@Autowired IPressService pressService) {
        this.pressService = pressService;
    }

    /**
     * 查询press列表
     */
    @Anonymous
    @GetMapping("/list")
    public AjaxResult list(Press press) {
        List<Press> list = pressService.selectPressList(press);

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 200);
        ajaxResult.put("rows", list);
        ajaxResult.put("total", list.size());
        return ajaxResult;
    }

    /**
     * 查询论文列表
     */
    @GetMapping("/pageList")
    public TableDataInfo pageList(Press press) {
        startPage();
        List<Press> list = pressService.selectPressList(press);
        return getDataTable(list);
    }

    /**
     * 获取press详细信息
     */
    @PreAuthorize("@ss.hasPermi('vr:press:query')")
    @GetMapping(value = "/{pressId}")
    public AjaxResult getInfo(@PathVariable("pressId") Long pressId) {
        return success(pressService.selectPressByPressId(pressId));
    }

    /**
     * 新增press
     */
    @PreAuthorize("@ss.hasPermi('vr:press:add')")
    @Log(title = "press", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Press press) {
        return toAjax(pressService.insertPress(press));
    }

    /**
     * 修改press
     */
    @PreAuthorize("@ss.hasPermi('vr:press:edit')")
    @Log(title = "press", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Press press) {
        return toAjax(pressService.updatePress(press));
    }

    /**
     * 删除press
     */
    @PreAuthorize("@ss.hasPermi('vr:press:remove')")
    @Log(title = "press", businessType = BusinessType.DELETE)
    @DeleteMapping("/{pressIds}")
    public AjaxResult remove(@PathVariable Long[] pressIds) {
        return toAjax(pressService.deletePressByPressIds(pressIds));
    }

    /**
     * 导出press列表
     */
    @PreAuthorize("@ss.hasPermi('vr:press:export')")
    @Log(title = "press", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Press press) {
        List<Press> list = pressService.selectPressList(press);
        ExcelUtil<Press> util = new ExcelUtil<
                >(Press.class);
        util.exportExcel(response, list, "press数据");
    }

    /**
     * 下载导入模板
     */
    @Anonymous
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response) throws IOException {
        List<PressImData> dataList = new ArrayList<>();
        EasyExcel.write(response.getOutputStream(), PressImData.class).sheet("Sheet1").doWrite(dataList);
    }

    /**
     * 导入数据
     */
    @Anonymous
    @PostMapping("/import")
    public AjaxResult importData(MultipartFile file, boolean updateSupport) throws IOException {

        List<Press> list = ExcelReadUtil.read(file, PressImData.class, Press.class);

        // 调用服务层方法进行数据导入处理
        String message = pressService.importData(list, updateSupport);

        // 返回成功响应，携带导入结果信息
        return AjaxResult.success(message);
    }

}
