package com.ruoyi.project.VRdemo.service.impl;


import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.VRdemo.mapper.PressMapper;
import com.ruoyi.project.VRdemo.domain.Press;
import com.ruoyi.project.VRdemo.service.IPressService;

/**
 * pressService业务层处理
 *
 * @author ruoyi
 * @date 2024-01-19
 */
@Service
public class PressServiceImpl implements IPressService {

    private final PressMapper pressMapper;

    public PressServiceImpl(@Autowired PressMapper pressMapper) {
        this.pressMapper = pressMapper;
    }

    /**
     * 查询press
     *
     * @param pressId press主键
     * @return press
     */
    @Override
    public Press selectPressByPressId(Long pressId) {
        return pressMapper.selectPressByPressId(pressId);
    }

    /**
     * 查询press列表
     *
     * @param press press
     * @return press
     */
    @Override
    public List<Press> selectPressList(Press press) {
        return pressMapper.selectPressList(press);
    }

    /**
     * 新增press
     *
     * @param press press
     * @return 结果
     */
    @Override
    public int insertPress(Press press) {
        press.setCreateTime(DateUtils.getNowDate());
        return pressMapper.insertPress(press);
    }

    /**
     * 修改press
     *
     * @param press press
     * @return 结果
     */
    @Override
    public int updatePress(Press press) {
        press.setUpdateTime(DateUtils.getNowDate());
        return pressMapper.updatePress(press);
    }

    /**
     * 批量删除press
     *
     * @param pressIds 需要删除的press主键
     * @return 结果
     */
    @Override
    public int deletePressByPressIds(Long[] pressIds) {
        return pressMapper.deletePressByPressIds(pressIds);
    }

    /**
     * 删除press信息
     *
     * @param pressId press主键
     * @return 结果
     */
    @Override
    public int deletePressByPressId(Long pressId) {
        return pressMapper.deletePressByPressId(pressId);
    }

    /**
     * 导入数据
     */
    @Override
    public String importData(List<Press> dataList, boolean updateSupport) {
        BulkImportService<Press> importService = new BulkImportService<>() {
            @Override
            protected Long checkExistingItem(Press item) {
                Press press = pressMapper.selectPressByTitle(item.getTitle());
                return press == null ? 0L : press.getPressId();
            }

            @Override
            protected boolean updateItem(Press item, Long id) {
                item.setPressId(id);
                item.setUpdateBy(SecurityUtils.getLoginUser().getUsername());
                item.setUpdateTime(DateUtils.getNowDate());
                return pressMapper.updatePress(item) > 0;
            }

            @Override
            protected boolean executeBatch(List<Press> batchDataList) {
                return pressMapper.insertPressDataList(batchDataList) > 0;
            }

            @Override
            protected String getItemTitle(Press item) {
                return item.getTitle();
            }
        };

        return importService.importData(dataList, updateSupport);
    }
}
