package com.ruoyi.project.VRdemo.service.impl;


import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.project.VRdemo.domain.Research;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.VRdemo.mapper.ResearchMapper;
import com.ruoyi.project.VRdemo.service.IResearchService;

/**
 * 研究Service业务层处理
 *
 * @author ruoyi
 * @date 2024-06-23
 */
@Service
public class ResearchServiceImpl implements IResearchService {

    private final ResearchMapper researchMapper;

    public ResearchServiceImpl(@Autowired ResearchMapper researchMapper) {
        this.researchMapper = researchMapper;
    }

    /**
     * 查询研究
     *
     * @param id 研究主键
     * @return 研究
     */
    @Override
    public Research selectResearchById(Long id) {
        return researchMapper.selectResearchById(id);
    }

    /**
     * 查询研究列表
     *
     * @param research 研究
     * @return 研究
     */
    @Override
    public List<Research> selectResearchList(Research research) {
        return researchMapper.selectResearchList(research);
    }

    /**
     * 新增研究
     *
     * @param research 研究
     * @return 结果
     */
    @Override
    public int insertResearch(Research research) {
        return researchMapper.insertResearch(research);
    }

    /**
     * 修改研究
     *
     * @param research 研究
     * @return 结果
     */
    @Override
    public int updateResearch(Research research) {
        return researchMapper.updateResearch(research);
    }

    /**
     * 批量删除研究
     *
     * @param ids 需要删除的研究主键
     * @return 结果
     */
    @Override
    public int deleteResearchByIds(Long[] ids) {
        return researchMapper.deleteResearchByIds(ids);
    }

    /**
     * 删除研究信息
     *
     * @param id 研究主键
     * @return 结果
     */
    @Override
    public int deleteResearchById(Long id) {
        return researchMapper.deleteResearchById(id);
    }

    /**
     * 导入数据
     */
    @Override
    public String importData(List<Research> dataList, boolean updateSupport) {
        BulkImportService<Research> importService = new BulkImportService<>() {
            @Override
            protected Long checkExistingItem(Research item) {
                Research research = researchMapper.selectResearchByTitle(item.getTitle());
                return research == null ? 0L : research.getId();
            }

            @Override
            protected boolean updateItem(Research item, Long id) {
                item.setId(id);
                item.setUpdateBy(SecurityUtils.getLoginUser().getUsername());
                item.setUpdateTime(DateUtils.getNowDate());
                return researchMapper.updateResearch(item) > 0;
            }

            @Override
            protected boolean executeBatch(List<Research> batchDataList) {
                return researchMapper.insertResearchDataList(batchDataList) > 0;
            }

            @Override
            protected String getItemTitle(Research item) {
                return item.getTitle();
            }
        };

        return importService.importData(dataList, updateSupport);
    }
}
