package com.ruoyi.project.VRdemo.service.impl;

import com.ruoyi.project.VRdemo.domain.Press;
import com.ruoyi.project.VRdemo.domain.Research;
import com.ruoyi.project.VRdemo.domain.SearchData;
import com.ruoyi.project.VRdemo.domain.Thesis;
import com.ruoyi.project.VRdemo.mapper.SearchDataMapper;
import com.ruoyi.project.VRdemo.service.ISearchService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

@Service
public class SearchServiceImpl implements ISearchService {

    @Autowired
    private SearchDataMapper searchDataMapper;

    @Override
    public List<Object> MappingSelection(List<SearchData> searchData) {
        String dataQueryType = searchData.get(0).getDataType();
        // 匹配数据类型
        switch (dataQueryType) {
            case "periodicals":
                return new ArrayList<>(handlePeriodicals(searchData));
            case "study":
                return new ArrayList<>(handleStudy(searchData));
            case "thesis":
                return new ArrayList<>(handleThesis(searchData));
            default:
                return null;
        }
    }

    /**
     * 开始分页
     *
     * @param list     传入的list集合
     * @param pageNum  页码
     * @param pageSize 每页多少条数据
     * @return
     */
    public List<Object> startPage(List<Object> list, Integer pageNum, Integer pageSize) {
        if (list == null) {
            return null;
        }
        if (list.size() == 0) {
            return null;
        }
        Integer count = list.size(); // 记录总数
        Integer pageCount = 0; // 页数
        if (count % pageSize == 0) {
            pageCount = count / pageSize;
        } else {
            pageCount = count / pageSize + 1;
        }
        int fromIndex = 0; // 开始索引
        int toIndex = 0; // 结束索引
        if (pageNum != pageCount) {
            fromIndex = (pageNum - 1) * pageSize;
            toIndex = fromIndex + pageSize;
        } else {
            fromIndex = (pageNum - 1) * pageSize;
            toIndex = count;
        }
        List pageList = list.subList(fromIndex, toIndex);
        return pageList;
    }

    // 期刊逻辑
    private List<Press> handlePeriodicals(List<SearchData> searchData) {
        StringBuilder SQL = new StringBuilder("SELECT * FROM vr_press WHERE ");
        analyticParameter(searchData, SQL);
        return searchDataMapper.ExecuteSearchPressSql(SQL.toString());
    }

    // 研究逻辑
    private List<Research> handleStudy(List<SearchData> searchData) {
        StringBuilder SQL = new StringBuilder("SELECT *,publication_time AS publicationTime FROM vr_research WHERE ");
        analyticParameter(searchData, SQL);
        return searchDataMapper.ExecuteSearchResearchSql(SQL.toString());
    }

    // 论文逻辑
    private List<Thesis> handleThesis(List<SearchData> searchData) {
        StringBuilder SQL = new StringBuilder("SELECT *,reply_time AS replyTime FROM vr_thesis WHERE ");
        analyticParameter(searchData, SQL);
        return searchDataMapper.ExecuteSearchThesisSql(SQL.toString());
    }


    public static void analyticParameter(List<SearchData> searchData, StringBuilder sql) {
        searchData.sort(Comparator.comparingInt(SearchData::getIndex));
        int searchDataSize = searchData.size();
        int timeJudgment = 0;
        for (int i = 0; i < searchDataSize; i++) {
            SearchData query = searchData.get(i);
            if (query.getIndex() == 90) {
                if (i == 0) {
                    sql.append(" ").append(query.getField_name()).append(" >= ").append("'").append(query.getText()).append("'");
                } else {
                    sql.append(" AND ").append(query.getField_name()).append(" >= ").append("'").append(query.getText()).append("'");
                }
                timeJudgment++;
                continue;
            } else if (query.getIndex() == 100) {
                timeJudgment++;
                if (timeJudgment == 2) {
                    sql.append(" AND ").append(query.getField_name()).append(" <= ").append("'").append(query.getText()).append("'");
                } else {
                    sql.append(" ").append(query.getField_name()).append(" <= ").append("'").append(query.getText()).append("'");
                }
                continue;
            }
            if (i != 0) {
                if (query.getQuery_concat().equals("NOT")) {
                    if (query.getQuery_style().equals("fuzzy")) {
                        sql.append(" AND ").append(query.getField_name()).append(" NOT ").append("LIKE '%").append(query.getText()).append("%'");
                    } else {
                        sql.append(" AND ").append(query.getField_name()).append(" <> ").append("'").append(query.getText()).append("'");
                    }
                    continue;
                } else {
                    sql.append(" ").append(query.getQuery_concat()).append(" ");
                }
            }
            if (searchDataSize == 1) {
                sql.append(parseLogicOperators(query.getField_name(), query.getText(), query.getQuery_style()));
                return;
            }
            sql.append(handleQueryCondition(query));
        }
    }

    private static String handleQueryCondition(SearchData query) {
        String text = query.getText();
        switch (query.getQuery_style()) {
            case "precise":
                return query.getField_name() + " = '" + text + "'";
            case "fuzzy":
                return query.getField_name() + " LIKE '%" + text + "%'";
            default:
                throw new IllegalArgumentException("Unsupported query style: " + query.getQuery_style());
        }
    }

    public static StringBuilder parseLogicOperators(String fieldName, String text, String queryStyle) {
        Map<String, String> replaceMap = new HashMap<>();
        replaceMap.put("*", "AND");
        replaceMap.put("+", "OR");
        replaceMap.put("-", "NOT");
        replaceMap.put("(", "(");
        replaceMap.put(")", ")");
        boolean needsReplacement = false;
        for (Map.Entry<String, String> entry : replaceMap.entrySet()) {
            if (text.contains(entry.getKey())) {
                needsReplacement = true;
                break;
            }
        }
        Pattern pattern = Pattern.compile("\"([^\"]*)\"");
        Matcher matcher = pattern.matcher(text);
        StringBuffer sb = new StringBuffer();
        String placeholder = "TEMP_PLUS_PLACEHOLDER";
        List<String> protectedContents = new ArrayList<>();
        while (matcher.find()) {
            protectedContents.add(matcher.group(1));
            matcher.appendReplacement(sb, placeholder);
        }
        matcher.appendTail(sb);
        text = sb.toString();
        if (needsReplacement) {
            for (Map.Entry<String, String> entry : replaceMap.entrySet()) {
                text = text.replace(entry.getKey(), entry.getValue());
            }
        }
        for (String protectedContent : protectedContents) {
            text = text.replaceFirst("TEMP_PLUS_PLACEHOLDER", protectedContent);
        }
        List<String> conditions = new ArrayList<>();
        Matcher conditionMatcher = Pattern.compile("\\(|\\)|\\bAND\\b|\\bOR\\b|\\bNOT\\b|[^\\s()]+").matcher(text);
        while (conditionMatcher.find()) {
            String match = conditionMatcher.group();
            if (!match.trim().isEmpty()) {
                conditions.add(match.trim());
            }
        }
        StringBuilder condition = new StringBuilder();
        boolean notFlag = false;
        for (String item : conditions) {
            if ("NOT".equals(item)) {
                condition.append(" AND ").append(fieldName).append(" NOT ");
                notFlag = true;
                continue;
            }
            boolean isLogicalOperatorOrBracket = "AND".equals(item) || "OR".equals(item) || "(".equals(item) || ")".equals(item);
            if (isLogicalOperatorOrBracket) {
                condition.append(" ").append(item).append(" ");
            } else if (notFlag) {
                condition.append("LIKE '%").append(item).append("%'");
                notFlag = false;
            } else {
                condition.append(fieldName).append(" LIKE '%").append(item).append("%'");
            }
        }
        return condition;
    }
}
