package com.ruoyi.project.VRdemo.service.impl;


import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.project.VRdemo.domain.Thesis;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.VRdemo.mapper.ThesisMapper;
import com.ruoyi.project.VRdemo.service.IThesisService;

/**
 * 论文Service业务层处理
 *
 * @author ruoyi
 * @date 2024-06-23
 */
@Service
public class ThesisServiceImpl implements IThesisService {

    private final ThesisMapper thesisMapper;

    public ThesisServiceImpl(@Autowired ThesisMapper thesisMapper) {
        this.thesisMapper = thesisMapper;
    }


    /**
     * 查询论文
     *
     * @param id 论文主键
     * @return 论文
     */
    @Override
    public Thesis selectThesisById(Long id) {
        return thesisMapper.selectThesisById(id);
    }

    /**
     * 查询论文列表
     *
     * @param thesis 论文
     * @return 论文
     */
    @Override
    public List<Thesis> selectThesisList(Thesis thesis) {
        return thesisMapper.selectThesisList(thesis);
    }

    /**
     * 新增论文
     *
     * @param thesis 论文
     * @return 结果
     */
    @Override
    public int insertThesis(Thesis thesis) {
        return thesisMapper.insertThesis(thesis);
    }

    /**
     * 修改论文
     *
     * @param thesis 论文
     * @return 结果
     */
    @Override
    public int updateThesis(Thesis thesis) {
        return thesisMapper.updateThesis(thesis);
    }

    /**
     * 批量删除论文
     *
     * @param ids 需要删除的论文主键
     * @return 结果
     */
    @Override
    public int deleteThesisByIds(Long[] ids) {
        return thesisMapper.deleteThesisByIds(ids);
    }

    /**
     * 删除论文信息
     *
     * @param id 论文主键
     * @return 结果
     */
    @Override
    public int deleteThesisById(Long id) {
        return thesisMapper.deleteThesisById(id);
    }

    /**
     * 导入数据
     */
    @Override
    public String importData(List<Thesis> dataList, boolean updateSupport) {
        BulkImportService<Thesis> importService = new BulkImportService<>() {
            @Override
            protected Long checkExistingItem(Thesis item) {
                Thesis thesis = thesisMapper.selectThesisByTitle(item.getTitle());
                return thesis == null ? 0L : thesis.getId();
            }

            @Override
            protected boolean updateItem(Thesis item, Long id) {
                item.setId(id);
                item.setUpdateBy(SecurityUtils.getLoginUser().getUsername());
                item.setUpdateTime(DateUtils.getNowDate());
                return thesisMapper.updateThesis(item) > 0;
            }

            @Override
            protected boolean executeBatch(List<Thesis> batchDataList) {
                return thesisMapper.insertThesisDataList(batchDataList) > 0;
            }

            @Override
            protected String getItemTitle(Thesis item) {
                return item.getTitle();
            }
        };

        return importService.importData(dataList, updateSupport);
    }
}
